@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1996-2020 The Octave Project Developers
+// Copyright (C) 1996-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -28,8 +28,6 @@
 
 #include "octave-config.h"
 
-#include <ctime>
-
 #include <string>
 
 #include "comment-list.h"
@@ -43,20 +41,17 @@ class string_vector;
 
 class octave_value;
 
-namespace octave
-{
-  class file_info;
-  class stack_frame;
-  class tree_parameter_list;
-  class tree_statement_list;
-  class tree_evaluator;
-  class tree_expression;
-  class tree_walker;
-#if defined (HAVE_LLVM)
-  class jit_function_info;
-#endif
+OCTAVE_BEGIN_NAMESPACE(octave)
 
-}
+class file_info;
+class stack_frame;
+class tree_parameter_list;
+class tree_statement_list;
+class tree_evaluator;
+class tree_expression;
+class tree_walker;
+
+OCTAVE_END_NAMESPACE(octave)
 
 class
 octave_user_code : public octave_function
@@ -67,10 +62,10 @@ protected:
                     const octave::symbol_scope& scope = octave::symbol_scope (),
                     octave::tree_statement_list *cmds = nullptr,
                     const std::string& ds = "")
-    : octave_function (nm, ds), m_scope (scope), file_name (fnm),
-      t_parsed (static_cast<time_t> (0)),
-      t_checked (static_cast<time_t> (0)),
-      m_file_info (nullptr), cmd_list (cmds)
+    : octave_function (nm, ds), m_scope (scope), m_file_name (fnm),
+      m_t_parsed (static_cast<OCTAVE_TIME_T> (0)),
+      m_t_checked (static_cast<OCTAVE_TIME_T> (0)),
+      m_file_info (nullptr), m_cmd_list (cmds)
   {
     if (m_scope)
       m_scope.set_user_code (this);
@@ -88,30 +83,32 @@ public:
 
   bool is_user_code (void) const { return true; }
 
-  std::string get_code_line (size_t line);
+  std::string get_code_line (std::size_t line);
 
-  std::deque<std::string> get_code_lines (size_t line, size_t num_lines);
+  std::deque<std::string> get_code_lines (std::size_t line,
+                                          std::size_t num_lines);
 
   void cache_function_text (const std::string& text,
                             const octave::sys::time& timestamp);
 
   octave::symbol_scope scope (void) { return m_scope; }
 
-  void stash_fcn_file_name (const std::string& nm) { file_name = nm; }
+  void stash_fcn_file_name (const std::string& nm) { m_file_name = nm; }
 
-  void mark_fcn_file_up_to_date (const octave::sys::time& t) { t_checked = t; }
+  void mark_fcn_file_up_to_date (const octave::sys::time& t)
+  { m_t_checked = t; }
 
   void stash_fcn_file_time (const octave::sys::time& t)
   {
-    t_parsed = t;
+    m_t_parsed = t;
     mark_fcn_file_up_to_date (t);
   }
 
-  std::string fcn_file_name (void) const { return file_name; }
+  std::string fcn_file_name (void) const { return m_file_name; }
 
-  octave::sys::time time_parsed (void) const { return t_parsed; }
+  octave::sys::time time_parsed (void) const { return m_t_parsed; }
 
-  octave::sys::time time_checked (void) const { return t_checked; }
+  octave::sys::time time_checked (void) const { return m_t_checked; }
 
   virtual octave_value find_subfunction (const std::string&) const
   {
@@ -120,7 +117,7 @@ public:
 
   virtual std::map<std::string, octave_value> subfunctions (void) const;
 
-  octave::tree_statement_list * body (void) { return cmd_list; }
+  octave::tree_statement_list * body (void) { return m_cmd_list; }
 
   octave_value dump (void) const;
 
@@ -132,21 +129,21 @@ protected:
   octave::symbol_scope m_scope;
 
   // The name of the file we parsed.
-  std::string file_name;
+  std::string m_file_name;
 
   // The time the file was parsed.
-  octave::sys::time t_parsed;
+  octave::sys::time m_t_parsed;
 
   // The time the file was last checked to see if it needs to be
   // parsed again.
-  octave::sys::time t_checked;
+  octave::sys::time m_t_checked;
 
   // Cached text of function or script code with line offsets
   // calculated.
   octave::file_info *m_file_info;
 
   // The list of commands that make up the body of this function.
-  octave::tree_statement_list *cmd_list;
+  octave::tree_statement_list *m_cmd_list;
 };
 
 // Scripts.
@@ -220,9 +217,9 @@ public:
 
   // No copying!
 
-  octave_user_function (const octave_user_function& fn) = delete;
+  octave_user_function (const octave_user_function& fcn) = delete;
 
-  octave_user_function& operator = (const octave_user_function& fn) = delete;
+  octave_user_function& operator = (const octave_user_function& fcn) = delete;
 
   ~octave_user_function (void);
 
@@ -238,35 +235,38 @@ public:
 
   void stash_fcn_location (int line, int col)
   {
-    location_line = line;
-    location_column = col;
+    m_location_line = line;
+    m_location_column = col;
   }
 
-  int beginning_line (void) const { return location_line; }
-  int beginning_column (void) const { return location_column; }
+  int beginning_line (void) const { return m_location_line; }
+  int beginning_column (void) const { return m_location_column; }
 
   void stash_fcn_end_location (int line, int col)
   {
-    end_location_line = line;
-    end_location_column = col;
+    m_end_location_line = line;
+    m_end_location_column = col;
   }
 
-  int ending_line (void) const { return end_location_line; }
-  int ending_column (void) const { return end_location_column; }
+  int ending_line (void) const { return m_end_location_line; }
+  int ending_column (void) const { return m_end_location_column; }
 
   void maybe_relocate_end (void);
 
-  void stash_parent_fcn_name (const std::string& p) { parent_name = p; }
-
   void stash_parent_fcn_scope (const octave::symbol_scope& ps);
 
-  void stash_leading_comment (octave::comment_list *lc) { lead_comm = lc; }
+  void stash_leading_comment (octave::comment_list *lc) { m_lead_comm = lc; }
 
-  void stash_trailing_comment (octave::comment_list *tc) { trail_comm = tc; }
+  void stash_trailing_comment (octave::comment_list *tc) { m_trail_comm = tc; }
 
   std::string profiler_name (void) const;
 
-  std::string parent_fcn_name (void) const { return parent_name; }
+  std::string parent_fcn_name (void) const
+  {
+    octave::symbol_scope pscope = parent_fcn_scope ();
+
+    return pscope.fcn_name ();
+  }
 
   octave::symbol_scope parent_fcn_scope (void) const
   {
@@ -280,7 +280,7 @@ public:
 
   void mark_as_system_fcn_file (void);
 
-  bool is_system_fcn_file (void) const { return system_fcn_file; }
+  bool is_system_fcn_file (void) const { return m_system_fcn_file; }
 
   bool is_user_function (void) const { return true; }
 
@@ -308,24 +308,24 @@ public:
 
   octave_value_list all_va_args (const octave_value_list& args);
 
-  void stash_function_name (const std::string& s) { my_name = s; }
+  void stash_function_name (const std::string& s) { m_name = s; }
 
-  void mark_as_subfunction (void) { subfunction = true; }
+  void mark_as_subfunction (void) { m_subfunction = true; }
 
-  bool is_subfunction (void) const { return subfunction; }
+  bool is_subfunction (void) const { return m_subfunction; }
 
-  void mark_as_inline_function (void) { inline_function = true; }
+  void mark_as_inline_function (void) { m_inline_function = true; }
 
-  bool is_inline_function (void) const { return inline_function; }
+  bool is_inline_function (void) const { return m_inline_function; }
 
-  void mark_as_anonymous_function (void) { anonymous_function = true; }
+  void mark_as_anonymous_function (void) { m_anonymous_function = true; }
 
-  bool is_anonymous_function (void) const { return anonymous_function; }
+  bool is_anonymous_function (void) const { return m_anonymous_function; }
 
   bool is_anonymous_function_of_class
   (const std::string& cname = "") const
   {
-    return anonymous_function
+    return m_anonymous_function
            ? (cname.empty ()
               ? (! dispatch_class ().empty ())
               : cname == dispatch_class ())
@@ -340,41 +340,41 @@ public:
     return is_inline_function () || is_anonymous_function ();
   }
 
-  void mark_as_nested_function (void) { nested_function = true; }
+  void mark_as_nested_function (void) { m_nested_function = true; }
 
-  bool is_nested_function (void) const { return nested_function; }
+  bool is_nested_function (void) const { return m_nested_function; }
 
   bool is_parent_function (void) const { return m_scope.is_parent (); }
 
-  void mark_as_legacy_constructor (void) { class_constructor = legacy; }
+  void mark_as_legacy_constructor (void) { m_class_constructor = legacy; }
 
   bool is_legacy_constructor (const std::string& cname = "") const
   {
-    return (class_constructor == legacy
+    return (m_class_constructor == legacy
             ? (cname.empty () ? true : cname == dispatch_class ()) : false);
   }
 
-  void mark_as_classdef_constructor (void) { class_constructor = classdef; }
+  void mark_as_classdef_constructor (void) { m_class_constructor = classdef; }
 
   bool is_classdef_constructor (const std::string& cname = "") const
   {
-    return (class_constructor == classdef
+    return (m_class_constructor == classdef
             ? (cname.empty () ? true : cname == dispatch_class ()) : false);
   }
 
-  void mark_as_legacy_method (void) { class_method = legacy; }
+  void mark_as_legacy_method (void) { m_class_method = legacy; }
 
   bool is_legacy_method (const std::string& cname = "") const
   {
-    return (class_method == legacy
+    return (m_class_method == legacy
             ? (cname.empty () ? true : cname == dispatch_class ()) : false);
   }
 
-  void mark_as_classdef_method (void) { class_method = classdef; }
+  void mark_as_classdef_method (void) { m_class_method = classdef; }
 
   bool is_classdef_method (const std::string& cname = "") const
   {
-    return (class_method == classdef
+    return (m_class_method == classdef
             ? (cname.empty () ? true : cname == dispatch_class ()) : false);
   }
 
@@ -391,13 +391,13 @@ public:
   execute (octave::tree_evaluator& tw, int nargout = 0,
            const octave_value_list& args = octave_value_list ());
 
-  octave::tree_parameter_list * parameter_list (void) { return param_list; }
+  octave::tree_parameter_list * parameter_list (void) { return m_param_list; }
 
-  octave::tree_parameter_list * return_list (void) { return ret_list; }
+  octave::tree_parameter_list * return_list (void) { return m_ret_list; }
 
-  octave::comment_list * leading_comment (void) { return lead_comm; }
+  octave::comment_list * leading_comment (void) { return m_lead_comm; }
 
-  octave::comment_list * trailing_comment (void) { return trail_comm; }
+  octave::comment_list * trailing_comment (void) { return m_trail_comm; }
 
   // If is_special_expr is true, retrieve the sigular expression that forms the
   // body.  May be null (even if is_special_expr is true).
@@ -407,12 +407,6 @@ public:
 
   void accept (octave::tree_walker& tw);
 
-#if defined (HAVE_LLVM)
-  octave::jit_function_info * get_info (void) { return jit_info; }
-
-  void stash_info (octave::jit_function_info *info) { jit_info = info; }
-#endif
-
   octave_value dump (void) const;
 
 private:
@@ -428,59 +422,49 @@ private:
   std::string method_type_str (void) const;
 
   // List of arguments for this function.  These are local variables.
-  octave::tree_parameter_list *param_list;
+  octave::tree_parameter_list *m_param_list;
 
   // List of parameters we return.  These are also local variables in
   // this function.
-  octave::tree_parameter_list *ret_list;
+  octave::tree_parameter_list *m_ret_list;
 
   // The comments preceding the FUNCTION token.
-  octave::comment_list *lead_comm;
+  octave::comment_list *m_lead_comm;
 
   // The comments preceding the ENDFUNCTION token.
-  octave::comment_list *trail_comm;
+  octave::comment_list *m_trail_comm;
 
   // Location where this function was defined.
-  int location_line;
-  int location_column;
-  int end_location_line;
-  int end_location_column;
-
-  // The name of the parent function, if any.
-  std::string parent_name;
+  int m_location_line;
+  int m_location_column;
+  int m_end_location_line;
+  int m_end_location_column;
 
   // True if this function came from a file that is considered to be a
   // system function.  This affects whether we check the time stamp
   // on the file to see if it has changed.
-  bool system_fcn_file;
+  bool m_system_fcn_file;
 
   // The number of arguments that have names.
-  int num_named_args;
+  int m_num_named_args;
 
-  // TRUE means this is a subfunction of a primary function.
-  bool subfunction;
+  // TRUE means this is a m_subfunction of a primary function.
+  bool m_subfunction;
 
   // TRUE means this is an inline function.
-  bool inline_function;
+  bool m_inline_function;
 
   // TRUE means this is an anonymous function.
-  bool anonymous_function;
+  bool m_anonymous_function;
 
   // TRUE means this is a nested function.
-  bool nested_function;
-
-  // TRUE means this function contains a nested function.
-  bool parent_function;
+  bool m_nested_function;
 
   // Enum describing whether this function is the constructor for class object.
-  class_method_type class_constructor;
+  class_method_type m_class_constructor;
 
   // Enum describing whether this function is a method for a class.
-  class_method_type class_method;
-
-#if defined (HAVE_LLVM)
-  octave::jit_function_info *jit_info;
-#endif
+  class_method_type m_class_method;
 
   void maybe_relocate_end_internal (void);
 
